==> skin.apptv-1.5.10.zip: skin.apptv/README.md <==
<p align="center">
<img src="http://mirrors.kodi.tv/addons/krypton/skin.apptv/resources/icon.png" width="128" align="middle">
</p>

## ABOUT AppTV
AppTV is a Kodi media centre skin that follows the design language of Apple's AppleTVs.  While there are elements of the original AppleTV interface, there are three Kodi home screens types available to allow the user to customise the look and feel to match each of the major design generations.
There are also a number of design ideas borrowed from Apple's iOS to help the user spot the currently focused user interface elements.  Also like the AppleTV user interface, sound is used thruout the skin to clue the user to what is happening on screen.  But unlike the Apple interface, this skin is heavily customisable. This allows the skin to be used on systems with a very small amount of resources (memory and processor capacity) while allowing more capable systems access to all of Kodi's advanced options.
While Kodi and thus this skin is built around the idea of a 10' interface, the skin has full support for mouse/touch. There is also full support for the Kodi PVR subsytem.
  
Created by Wyrm


## DEVELOPMENT:
[Github](https://github.com/wyrm65/skin.apptv)

## LINKS:
[Kodi forum (skin support)](http://forum.Kodi.org/forumdisplay.php?fid=76)

[Kodi Wiki](https://kodi.wiki/view/Add-on:AppTV)

[Screenshots](https://kodi.wiki/view/Add-on:AppTV#Screenshots)

## INSTALL   
Can be installed through the official Kodi repository.
To install this add-on you must do so from the Add-on manager from within Kodi by going to:   

1. Settings   
2. Add-ons   
3. Install from repository   
4. Kodi add-on repository   
5. Look and feel   
6. Skins   
7. AppTV   
8. Install   

## DEPENDANT ADDONS   
While I have tried very hard for the skin to be self contained, the following addons are required for the installation.  These addons will be installed if not already in the users system when the skin is installed via the offical Kodi repository.  The user will need to ensure these addons are available if installing via a zip file from this github page.

resource.uisounds.apptv v1.0.4  
script.skin.helper.service v1.1.3  
script.skin.helper.widgets v1.0.22  

## OPTIONAL ADDONS
The following addons will be made use of if installed by the user.  The skin will prompt the user to allow the installation of any necessary addons if the user selects an option requiring an addon.  In addition a number of the optional addons can be installed via the skins settings menus.

script.libraryeditor  
script.cdartmanager  
script.favourites  
script.tv.show.next.aired  
script.cinemavision  
plugin.video.specialfeatures  
script globalsearch  
script.artistslideshow  
script.image.resource.select  
script.kodi.loguploader  

## SCRIPTS WITH SKINABLE ELEMENTS
The following scripts are supported with custom skin files to match the script to the rest of the skin

script.cu.lrclyrics  
script.globalsearch  
script.tv.show.next.aired  
service.nextup.notification  
plugin.video.specialfeatures  
script.extendedinfo  
service.libreelec.settings

==> skin.apptv-1.6.6.zip: skin.apptv/README.md <==
<p align="center">
<img src="http://mirrors.kodi.tv/addons/krypton/skin.apptv/resources/icon.png" width="128" align="middle">
</p>

## ABOUT AppTV
AppTV is a Kodi media centre skin that follows the design language of Apple's AppleTVs.  While there are elements of the original AppleTV interface, there are three Kodi home screens types available to allow the user to customise the look and feel to match each of the major design generations.
There are also a number of design ideas borrowed from Apple's iOS to help the user spot the currently focused user interface elements.  Also like the AppleTV user interface, sound is used thruout the skin to clue the user to what is happening on screen.  But unlike the Apple interface, this skin is heavily customisable. This allows the skin to be used on systems with a very small amount of resources (memory and processor capacity) while allowing more capable systems access to all of Kodi's advanced options.
While Kodi and thus this skin is built around the idea of a 10' interface, the skin has full support for mouse/touch. There is also full support for the Kodi PVR subsytem.

Created by Wyrm


## DEVELOPMENT:
[Github](https://github.com/wyrm65/skin.apptv)

## LINKS:
[Kodi forum (skin support)](https://forum.kodi.tv/forumdisplay.php?fid=76)

[Kodi Wiki](https://kodi.wiki/view/Add-on:AppTV)

[Screenshots](https://kodi.wiki/view/Add-on:AppTV#Screenshots)

## INSTALL
Can be installed through the official Kodi repository.
To install this add-on you must do so from the Add-on manager from within Kodi by going to:

1. Settings
2. Add-ons
3. Install from repository
4. Kodi add-on repository
5. Look and feel
6. Skins
7. AppTV
8. Install

## DEPENDANT ADDONS
While I have tried very hard for the skin to be self contained, the following addons are required for the installation.  These addons will be installed if not already in the users system when the skin is installed via the offical Kodi repository.  The user will need to ensure these addons are available if installing via a zip file from this github page.

 - resource.uisounds.apptv v1.0.4
 - resource.images.classificationicons.colour v0.0.3
 - script.embuary.helper v1.4.8

## OPTIONAL ADDONS
The following addons will be made use of if installed by the user.  The skin will prompt the user to allow the installation of any necessary addons if the user selects an option requiring an addon.  In addition a number of the optional addons can be installed via the skins settings menus.

 - script.artistslideshow
 - service.tvtunes
 - plugin.program.autocompletion
 - script.cu.lrclyrics
 - script.globalsearch
 - script.image.resource.select
 - service.upnext
 - script.tv.show.next.aired
 - script.artwork.beef
 - script.metadata.editor
 - script.libraryeditor
 - script.favourites
 - plugin.video.specialfeatures
 - script.kodi.loguploader

## SCRIPTS WITH SKINABLE ELEMENTS
The following scripts are supported with custom skin files to match the script to the rest of the skin

 - script.cu.lrclyrics
 - script.globalsearch
 - script.tv.show.next.aired
 - service.upnext
 - plugin.video.specialfeatures
 - service.libreelec.settings
